@@ -6,6 +6,10 @@ class InstanceNotFoundError(HardwareGatewayError):
     pass
 
 
+class InstanceLockedError(HardwareGatewayError):
+    pass
+
+
 class InvalidMethodError(HardwareGatewayError):
     pass
 
@@ -14,6 +18,10 @@ class InstanceAlreadyRegisteredError(HardwareGatewayError):
     pass
 
 
+class InstanceReadOnly(HardwareGatewayError):
+    pass
+
+
 class InvalidMessageError(HardwareGatewayError):
     pass
 
